values

package
v0.6.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 31, 2025 License: Apache-2.0 Imports: 6 Imported by: 0

Documentation

Overview

Package values serializes and deserializes values.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Pack

func Pack(val keyval.Value, order binary.ByteOrder, vstamp bool) ([]byte, error)

Pack serializes keyval.Value into a bytes string for writing to the DB.

func Unpack

func Unpack(val []byte, typ keyval.ValueType, order binary.ByteOrder) (keyval.Value, error)

Unpack deserializes keyval.Value from a byte string read from the DB.

Types

type UnexpectedValueTypeErr

type UnexpectedValueTypeErr struct {
	// contains filtered or unexported fields
}

UnexpectedValueTypeErr is returned by Unpack if the provided keyval.ValueType is not implemented. This error should only occur if a bug is present in the code.

Jump to